@@ -92,7 +92,7 @@ BROAD_HOSTS = netaddr.IPSet([
 
 # regular hosts
 REGULAR_HOSTS = netaddr.IPSet([
-    netaddr.IPNetwork('10.1/20'),
+    netaddr.IPNetwork('10.1/19'),
     netaddr.IPNetwork('10.1.128/24'),
     netaddr.IPNetwork('10.75.0/20'),
     netaddr.IPNetwork('10.75.100/22'),
@@ -217,7 +217,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if entry.ip not in self.ips:
                 self.ips[entry.ip] = line
             else:
-                warning = 'Duplicate Available IP Address: %s' % (entry.ip)
+                warning = f"Duplicate Available IP Address: {entry.ip}"
                 line.warnings.append(warning)
 
     def check_duplicate_hosts(self, kind='entry'):  # noqa: C901
@@ -241,7 +241,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if hostname not in self.hostnames:
                 self.hostnames[hostname] = line
             else:
-                error = 'Duplicate Hostname: %s' % (hostname)
+                error = f"Duplicate Hostname: {hostname}"
                 line.errors.append(error)
 
             # check cnames
@@ -250,7 +250,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 if cname not in self.hostnames:
                     self.hostnames[cname] = line
                 else:
-                    error = 'Duplicate Hostname: %s' % (cname)
+                    error = f"Duplicate Hostname: {cname}"
                     line.errors.append(error)
 
             # check ip address
@@ -258,7 +258,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 if entry.ip not in self.ips:
                     self.ips[entry.ip] = line
                 else:
-                    error = 'Duplicate IP Address: %s' % (entry.ip)
+                    error = f"Duplicate IP Address: {entry.ip}"
                     line.errors.append(error)
 
             # check mac address
@@ -268,7 +268,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                     if mac not in self.macs:
                         self.macs[mac] = line
                     else:
-                        error = 'Duplicate MAC Address: %s' % (mac)
+                        error = f"Duplicate MAC Address: {mac}"
                         line.errors.append(error)
 
     def check_duplicate_reserved_ips(self):
@@ -280,7 +280,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if entry.ip not in self.ips:
                 self.ips[entry.ip] = line
             else:
-                warning = 'Duplicate Reserved IP Address: %s' % (entry.ip)
+                warning = f"Duplicate Reserved IP Address: {entry.ip}"
                 line.warnings.append(warning)
 
     def check_duplicates(self):
@@ -326,7 +326,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if not line.entry.ip:
                 continue
             subnet = '.'.join(line.entry.ip.split('.')[:3])
-            cidr = netaddr.IPNetwork('%s.0/24' % (subnet))
+            cidr = netaddr.IPNetwork(f"{subnet}.0/24")
             if cidr not in subnets:
                 subnets[cidr] = []
             subnets[cidr].append(netaddr.IPAddress(line.entry.ip))
@@ -353,10 +353,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
 
             # display missiong IP addresses
             if self.verbose:
-                print('%s missing IPs: %s' % (
-                    subnet,
-                    len(missing),
-                ))
+                print(f"{subnet} missing IPs: {len(missing)}")
 
         return sorted(missing_ips)
 
@@ -364,19 +361,19 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
         """Display errors."""
         errors = self.get_errors()
         if errors:
-            print('\nERRORS [%s]:' % (len(errors)))
+            print(f"\nERRORS [{len(errors)}]:")
             for line in errors:
-                print('\n%s: %s' % (line.linenum, line.line))
-                print('  - ' + '\n  - '.join(line.errors))
+                print(f"\n{line.linenum}: {line.line}")
+                print("  - \n - ".join(line.errors))
 
     def display_warnings(self):
         """Display warnings."""
         warnings = self.get_warnings()
         if warnings:
-            print('\nWarnings [%s]:' % (len(warnings)))
+            print(f"\nWarnings [{len(warnings)}]:")
             for line in warnings:
-                print('\n%s: %s' % (line.linenum, line.line))
-                print('  - ' + '\n  - '.join(line.warnings))
+                print(f"\n{line.linenum}: {line.line}")
+                print("  - \n - ".join(line.warnings))
 
     def get_errors(self):
         """Return a list of lines with errors."""
@@ -437,7 +434,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             try:
                 ipaddr = netaddr.IPAddress(line.entry.ip)
             except Exception as exc:
-                print('%s\n\t%s' % (line.line, exc))
+                print(f"%{line.line}\n\t{str(exc)}")
                 continue
 
             # check the order of the ip addresses in the file
@@ -445,7 +442,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 last_ip = ipaddr
             else:
                 if last_ip > ipaddr:
-                    error = 'IP Address out of order: %s' % (line.entry.ip)
+                    error = f"IP Address out of order: {line.entry.ip}"
                     line.errors.append(error)
                 last_ip = ipaddr
 
@@ -465,7 +462,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 if hostname not in self.cnames:
                     self.cnames[hostname] = entry
                 else:
-                    error = 'Duplicate CNAME: %s' % (hostname)
+                    error = f"Duplicate CNAME: {hostname}"
                     line.errors.append(error)
             # mx
             elif entry.type == 'mx':
@@ -484,7 +481,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 if hostname not in self.hosts:
                     self.hosts[hostname] = entry
                 else:
-                    error = 'Duplicate Host: %s' % (hostname)
+                    error = f"Duplicate Host: {hostname}"
                     line.errors.append(error)
 
         # now that we've turned the entries into records, check for duplicates
@@ -494,7 +491,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if hostname not in self.records:
                 self.records[hostname] = data
             else:
-                error = 'Duplicate Record [CNAME]: %s' % (hostname)
+                error = f"Duplicate Record [CNAME]: {hostname}"
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # mx records
@@ -502,7 +499,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if hostname not in self.records:
                 self.records[hostname] = data
             else:
-                error = 'Duplicate Record [MX]: %s' % (hostname)
+                error = f"Duplicate Record [MX]: {hostname}"
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # ns records
@@ -510,7 +507,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if hostname not in self.records:
                 self.records[hostname] = data
             else:
-                error = 'Duplicate Record [NS]: %s' % (hostname)
+                error = f"Duplicate Record [NS]: {hostname}"
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # hosts
@@ -518,7 +515,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if hostname not in self.records:
                 self.records[hostname] = data
             else:
-                error = 'Duplicate Record [Host]: %s' % (hostname)
+                error = f"Duplicate Record [Host]: {hostname}"
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
     def get_record_types(self):
@@ -582,11 +579,11 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                 if host.owner:
                     host.owner.emplid = emplids[username]
                 else:
-                    print('Host owner not found: %s [%s]' % (hostname, username))
+                    print(f"Host owner not found: {hostname} [{username}]")
 
     def readlines(self):
         """Read in the lines of the MHL file."""
-        with open(self.path, "r") as mhlfile:
+        with open(self.path, "r", encoding="ascii") as mhlfile:
             return mhlfile.readlines()
 
     def update_file(self):
@@ -617,20 +614,18 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     def writelines(self, filename):
         """Write out the MHL file to disk."""
         # write out a new copy of the mhl to disk
-        with open(filename, "w") as outputfile:
+        with open(filename, "w", encoding="ascii") as outputfile:
             lines = []
             for line in self.lines:
-                lines.append('%s\n' % (line.line))
+                lines.append(f"{line.line}\n")
             outputfile.writelines(lines)
 
     def writemissing(self, filename):
         """Write out the MHL file to disk including missing IPs."""
         # write out a new copy of the mhl to disk
-        with open(filename, "w") as outputfile:
+        with open(filename, "w", encoding="ascii") as outputfile:
             lines = []
-
             missing_ips = sorted(self.missing_ips)
-
             last_ip = None
 
             for line in self.lines:
@@ -642,9 +637,9 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
                     last_ip = ipaddr
 
                 while ipaddr and missing_ips and ipaddr > missing_ips[0]:
-                    lines.append('#%s\n' % (missing_ips.pop(0)))
+                    lines.append(f"#{missing_ips.pop(0)}\n")
 
-                lines.append('%s\n' % (line.line))
+                lines.append(f"{line.line}\n")
             outputfile.writelines(lines)
 
 
@@ -704,10 +699,10 @@ class MHLLine(object):
             netaddr.IPAddress(ipaddr)
             # check if this ip address is in one of our known ranges
             if ipaddr not in self.broad_hosts:
-                error = 'Unknown Network: %s' % (ipaddr)
+                error = f"Unknown Network: {ipaddr}"
                 self.warnings.append(error)
         except netaddr.core.AddrFormatError:
-            error = 'Invalid IP Address: %s' % (ipaddr)
+            error = f"Invalid IP Address: {ipaddr}"
             errors.append(error)
         return errors
 
@@ -719,7 +714,7 @@ class MHLLine(object):
 
         # errors
         if self.kind == 'error':
-            error = 'Incorrect Field Count: %s' % (len(self.fields))
+            error = f"Incorrect Field Count: {len(self.fields)}"
             self.errors.append(error)
             return None
 
