@@ -36,13 +36,13 @@ class BaseType(object):
         try:
             netaddr.IPAddress(self.ip)
         except netaddr.core.AddrFormatError:
-            error = 'Invalid IP Address: %s' % (self.ip)
+            error = f"Invalid IP Address: {self.ip}"
             self.line.errors.append(error)
             return
 
         # check if this ip address is in one of our known ranges
         if self.ip not in self.line.broad_hosts and self.hosttype != 'external':
-            error = 'Unknown Network: %s' % (self.ip)
+            error = f"Unknown Network: {self.ip}"
             self.line.errors.append(error)
 
 
@@ -90,7 +90,7 @@ class BaseRecord(BaseType):
     def check_comments(self):
         """Check Comments."""
         if not self.comments:
-            error = 'Comments required: %s' % (self.comments)
+            error = f"Comments required: {self.comments}"
             self.line.errors.append(error)
 
     def check_hostname(self, hostname=None):
@@ -106,13 +106,13 @@ class BaseRecord(BaseType):
         if self.type in ['cname', 'mx', 'ns']:
             hostname = hostname.replace('.', '')
         if not hostre.match(hostname):
-            error = 'Hostname syntax: %s' % (hostname)
+            error = f"Hostname syntax: {hostname}"
             self.line.errors.append(error)
 
     def check_hosttype(self):
         """Check hosttype."""
         if self.hosttype not in self.line.hosttypes:
-            error = 'Invalid Type: %s' % (self.hosttype)
+            error = f"Invalid Type: {self.hosttype}"
             self.line.errors.append(error)
 
     def check_ttl(self):
@@ -121,7 +121,7 @@ class BaseRecord(BaseType):
         ttlre = TTLRE
         if not ttlre.match(self.ttl):
             if self.ttl != '-':
-                error = 'TTL syntax: %s' % (self.ttl)
+                error = f"TTL syntax: {self.ttl}"
                 self.line.errors.append(error)
 
 
@@ -164,13 +164,13 @@ class CnameRecord(DnsRecord):
         if not ttl:
             ttl = None
         data = {
-            u'comments': unicode(self.comments),
-            u'host_type': unicode(self.type),
-            u'id': unicode(self.hostname),
-            u'kind': u'dns#cname',
-            u'name': unicode(self.hostname),
-            u'ttl': ttl,
-            u'value': unicode(self.target),
+            'comments': unicode(self.comments),
+            'host_type': unicode(self.type),
+            'id': unicode(self.hostname),
+            'kind': 'dns#cname',
+            'name': unicode(self.hostname),
+            'ttl': ttl,
+            'value': unicode(self.target),
         }
         return data
 
@@ -198,14 +198,14 @@ class Comment(BaseType):
             self.check_ip()
             comment = self.line.fields[1]
             if not re.match('RESERVED - ', comment):
-                error = 'Invalid Comment: %s' % (comment)
+                error = f"Invalid Comment: {comment}"
                 self.line.warnings.append(error)
 
         elif self.comment_type == 'available_ip':
             self.check_ip()
 
         elif self.comment_type == 'error':
-            error = 'Invalid Comment: %s' % (comment)
+            error = f"Invalid Comment: {comment}"
             self.line.warnings.append(error)
 
     def get_comment_type(self):
@@ -306,7 +306,7 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
 
             # check format of comment
             if not re.match(r"[a-zA-Z-'\. ]+ \(.*\).*$", self.comments):
-                error = 'Invalid Comments format: %s' % (self.comments)
+                error = f"Invalid Comments format: {self.comments}"
                 self.line.errors.append(error)
                 return
 
@@ -314,7 +314,7 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
         """Check to make sure computed hostname exists."""
         hostname = self.get_computed_hostname()
         if hostname != self.hostname and hostname not in self.cnames:
-            error = 'Computed Hostname not found: %s' % (hostname)
+            error = f"Computed Hostname not found: {hostname}"
             self.line.errors.append(error)
 
     def check_location(self):
@@ -335,12 +335,12 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
             if not required:  # pylint:disable=no-else-return
                 return
             else:
-                error = 'Location required: %s' % (self.location)
+                error = f"Location required: {self.location}"
                 self.line.errors.append(error)
                 return
 
         if self.location not in self.line.locations:
-            error = 'Unknown Location: %s' % (self.location)
+            error = f"Unknown Location: {self.location}"
             self.line.errors.append(error)
 
     def check_mac(self):
@@ -359,20 +359,20 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
             if not required:  # pylint:disable=no-else-return
                 return
             else:
-                error = 'MAC Address required: %s' % (self.mac)
+                error = f"MAC Address required: {self.mac}"
                 self.line.errors.append(error)
                 return
 
         try:
             test_mac = netaddr.EUI(self.mac, dialect=netaddr.mac_unix_expanded)
         except netaddr.core.AddrFormatError:
-            error = 'Invalid MAC address: %s' % (self.mac)
+            error = f"Invalid MAC address: {self.mac}"
             self.line.errors.append(error)
             return
 
         # Make sure it's also in strict MAC/Unix expanded format
         if self.mac != str(test_mac):
-            error = 'Invalid MAC address: %s' % (self.mac)
+            error = f"Invalid MAC address: {self.mac}"
             self.line.errors.append(error)
 
     def check_owner(self):
@@ -401,15 +401,15 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
         type_char = self.hosttype[0]
         mac_name = self.get_mac_name()
         site_name = self.get_site_name()
-        return '%s%s%s' % (site_name, type_char, mac_name)
+        return f"{site_name}{type_char}{mac_name}"
 
     def get_mac_name(self):
         """Return MAC address portion of the computed hostname."""
         try:
             (mac4, mac5, mac6) = self.mac.split(':')[3:]
-            return '%s%s-%s%s' % (mac4, mac5[0], mac5[1], mac6)
+            return f"{mac4}{mac5[0]}-{mac5[1]}{mac6}"
         except Exception as exc:
-            error = 'ERROR generating mac name: %s (%s)' % (self.mac, str(exc))
+            error = f"ERROR generating mac name: {self.mac} ({str(exc)})"
             self.line.errors.append(error)
 
         return None
@@ -428,19 +428,19 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
 
         # cellario hosts get the "c"
         elif ipaddr in self.line.cellario_hosts:
-            return '%sc' % (self.location)
+            return f"{self.location}c"
 
         # lab hosts get the "l"
         elif ipaddr in self.line.lab_hosts:
-            return '%sl' % (self.location)
+            return f"{self.location}l"
 
         # qa hosts get the "q"
         elif ipaddr in self.line.qa_hosts:
-            return '%sq' % (self.location)
+            return f"{self.location}q"
 
         # restricted vlan hosts get an "x"
         elif ipaddr in self.line.restricted_hosts:
-            return '%sx' % (self.location)
+            return f"{self.location}x"
 
         # other known hosts get no tag
         else:
@@ -515,23 +515,23 @@ class Host(BaseRecord):  # pylint:disable=too-many-instance-attributes
             username = unicode(username)
 
         bitsdb = {
-            u'cnames': cnames,
-            u'comments': unicode(self.comments),
-            u'emplid': emplid,
-            u'hostname': unicode(self.hostname),
-            u'id': unicode(self.hostname),
-            u'ip': unicode(self.ip),
-            u'kind': u'host',
-            u'location': location,
-            u'mac': mac,
-            u'model': model,
-            u'name': unicode(self.hostname),
-            u'owner': owner,
-            u'round_robin': round_robin,
-            u'tags': tags,
-            u'ttl': ttl,
-            u'type': unicode(self.hosttype),
-            u'username': username,
+            'cnames': cnames,
+            'comments': unicode(self.comments),
+            'emplid': emplid,
+            'hostname': unicode(self.hostname),
+            'id': unicode(self.hostname),
+            'ip': unicode(self.ip),
+            'kind': 'host',
+            'location': location,
+            'mac': mac,
+            'model': model,
+            'name': unicode(self.hostname),
+            'owner': owner,
+            'round_robin': round_robin,
+            'tags': tags,
+            'ttl': ttl,
+            'type': unicode(self.hosttype),
+            'username': username,
         }
         return bitsdb
 
@@ -545,7 +545,7 @@ class MxRecord(DnsRecord):
         self.priority = self.data['mac']
         target = self.data['target']
         if self.priority:
-            target = '%s %s' % (self.priority, target)
+            target = f"{self.priority} {target}"
         self.targets = [target]
 
     def check(self):
@@ -561,7 +561,7 @@ class MxRecord(DnsRecord):
         try:
             int(self.priority)
         except Exception as exc:
-            error = 'Invalid MX Priority: %s [%s]' % (self.priority, exc)
+            error = f"Invalid MX Priority: {self.priority} [{str(exc)}]"
             self.line.errors.append(error)
 
     def to_json(self):
@@ -573,13 +573,13 @@ class MxRecord(DnsRecord):
         for target in self.targets:
             targets.append(unicode(target))
         data = {
-            u'comments': unicode(self.comments),
-            u'host_type': unicode(self.type),
-            u'id': unicode(self.hostname),
-            u'kind': u'dns#mx',
-            u'name': unicode(self.hostname),
-            u'ttl': ttl,
-            u'values': targets,
+            'comments': unicode(self.comments),
+            'host_type': unicode(self.type),
+            'id': unicode(self.hostname),
+            'kind': 'dns#mx',
+            'name': unicode(self.hostname),
+            'ttl': ttl,
+            'values': targets,
         }
         return data
 
@@ -610,13 +610,13 @@ class NsRecord(DnsRecord):
         for target in self.targets:
             targets.append(unicode(target))
         data = {
-            u'comments': unicode(self.comments),
-            u'host_type': unicode(self.type),
-            u'id': unicode(self.hostname),
-            u'kind': u'dns#ns',
-            u'name': unicode(self.hostname),
-            u'ttl': ttl,
-            u'values': targets,
+            'comments': unicode(self.comments),
+            'host_type': unicode(self.type),
+            'id': unicode(self.hostname),
+            'kind': 'dns#ns',
+            'name': unicode(self.hostname),
+            'ttl': ttl,
+            'values': targets,
         }
         return data
 
@@ -635,5 +635,5 @@ class ReservedIp(BaseType):
         """Run checks for a reserved IP entry."""
         self.check_ip()
         if not re.match('RESERVED - ', self.comments):
-            error = 'Invalid Comment: %s' % (self.comments)
+            error = f"Invalid Comment: {self.comments}"
             self.line.warnings.append(error)
